==> xpostitplus_2.3.orig.tar.gz: xpostitplus-2.3.orig/app_defaults.h <==
"XPostitPlus.geometry:               70x70-0+0",
"XPostitPlus.noteDir:                .postitnotes",
"XPostitPlus.Menu*cursor:            hand1",
"XPostitPlus.printCmd:		\"lpr %s\"",
"XPostitPlus.calendarCmd:		cal",
"XPostitPlus.nameWidth:              10",
"XPostitPlus*Command*font:		-adobe-helvetica-bold-r-normal--*-120-*-*-*-*-*-*",
"XPostitPlus*Menu*font:			-adobe-helvetica-medium-r-normal--*-120-*-*-*-*-*-*",
"XPostitPlus*List*font:			10x20",
"XPostitPlus*Text*font:			-b&h-lucidatypewriter-medium-r-normal-*-*-120-*-*-*-*-*-*",
"XPostitPlus*TimerText*font:	-b&h-lucidatypewriter-medium-r-normal-*-*-120-*-*-*-*-*-*",
"XPostitPlus*InsertLabel*font:	-b&h-lucidatypewriter-medium-r-normal-*-*-120-*-*-*-*-*-*",
"XPostitPlus.PostItNote*text*font:					\
										7x13bold",
"XPostitPlus*FileSelectionShell*List*font:			\
										-adobe-helvetica-bold-r-normal--*-120-*-*-*-*-*-*",
"XPostitPlus*Background:		PeachPuff",
"XPostitPlus*Foreground:		NavyBlue",
"XPostitPlus*Text*Background:	Yellow",
"XPostitPlus*Text*Foreground:	Black",
"XPostitPlus*List*Background:	gray",
"XPostitPlus*List*Foreground:	blue",
"XPostitPlus*Plaid*Background:	coral",
"XPostitPlus*Plaid*Foreground:	Black",
"XPostitPlus*PostItNote*Background:			Yellow",
"XPostitPlus*PostItNote*Foreground:			gray",
"XPostitPlus*PostItNote*Note*Background:	gray",
"XPostitPlus*PostItNote*Note*Foreground:	Wheat",
"XPostitPlus*PostItNote*Note*Options*Background:		gray",
"XPostitPlus*PostItNote*Note*Options*Foreground:		blue",
"XPostitPlus*PostItNote*Note*File*Background:			gray",
"XPostitPlus*PostItNote*Note*File*Foreground:			blue",
"XPostitPlus*PostItNote*Note*AlarmIcon*Background:	gray",
"XPostitPlus*PostItNote*Note*AlarmIcon*Foreground:	blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*Background:			gray",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*Foreground:			black",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*Save*Foreground:		blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*Erase*Foreground:		blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*Destroy*Foreground:		red",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*Hide*Foreground:		blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*Name*Foreground:		blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*Anchor*Foreground:		blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*UnAnchor*Foreground:	blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*Print*Foreground:		blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*SetAlarm*Foreground:	blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*UnsetAlarm*Foreground:	blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*InsertCalendar*Foreground:	blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*InsertDate*Foreground:	blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*EmailNote*Foreground:	blue",
"XPostitPlus*PostItNote*Note*Label*Background:	red",
"XPostitPlus*PostItNote*Note*Label*Foreground:	white",
"XPostitPlus*PostItNote*Note*NoteText*Background:	Yellow",
"XPostitPlus*PostItNote*Note*NoteText*Foreground:	Black",
"XPostitPlus*Command*Background:	red",
"XPostitPlus*Command*Foreground:	white",
"XPostitPlus*Text*wrap:		word",
"XPostitPlus*Command*shapeStyle:	oval",
"XPostitPlus*input:			true",
"XPostitPlus*Dialog*Text.Translations: #override\\n \
	<Key>Down:		no-op(RingBell) \\n \
	<Key>Return:		no-op(RingBell) \\n \
	Ctrl<Key>M:		no-op(RingBell)",
"XPostitPlus*Plaid.Translations: #replace\\n \
	<Btn1Down>:	raise()	\\n\
	<Btn2Down>:	lower()	\\n\
	<Btn3Down>:	XawPositionSimpleMenu(Menu) MenuPopup(Menu)",

==> xpostitplus_2.3.1.orig.tar.gz: xpostitplus-2.3.1.orig/app_defaults.h <==
"XPostitPlus.geometry:               70x70-0+0",
"XPostitPlus.noteDir:                .postitnotes",
"XPostitPlus.Menu*cursor:            hand1",
"XPostitPlus.printCmd:		\"lpr %s\"",
"XPostitPlus.calendarCmd:		cal",
"XPostitPlus.nameWidth:              10",
"XPostitPlus*Command*font:		-adobe-helvetica-bold-r-normal--*-120-*-*-*-*-*-*",
"XPostitPlus*Menu*font:			-adobe-helvetica-medium-r-normal--*-120-*-*-*-*-*-*",
"XPostitPlus*List*font:			10x20",
"XPostitPlus*Text*font:			-b&h-lucidatypewriter-medium-r-normal-*-*-120-*-*-*-*-*-*",
"XPostitPlus*TimerText*font:	-b&h-lucidatypewriter-medium-r-normal-*-*-120-*-*-*-*-*-*",
"XPostitPlus*InsertLabel*font:	-b&h-lucidatypewriter-medium-r-normal-*-*-120-*-*-*-*-*-*",
"XPostitPlus.PostItNote*text*font:					\
										7x13bold",
"XPostitPlus*FileSelectionShell*List*font:			\
										-adobe-helvetica-bold-r-normal--*-120-*-*-*-*-*-*",
"XPostitPlus*Background:		PeachPuff",
"XPostitPlus*Foreground:		NavyBlue",
"XPostitPlus*Text*Background:	Yellow",
"XPostitPlus*Text*Foreground:	Black",
"XPostitPlus*List*Background:	gray",
"XPostitPlus*List*Foreground:	blue",
"XPostitPlus*Plaid*Background:	coral",
"XPostitPlus*Plaid*Foreground:	Black",
"XPostitPlus*PostItNote*Background:			Yellow",
"XPostitPlus*PostItNote*Foreground:			gray",
"XPostitPlus*PostItNote*Note*Background:	gray",
"XPostitPlus*PostItNote*Note*Foreground:	Wheat",
"XPostitPlus*PostItNote*Note*Options*Background:		gray",
"XPostitPlus*PostItNote*Note*Options*Foreground:		blue",
"XPostitPlus*PostItNote*Note*File*Background:			gray",
"XPostitPlus*PostItNote*Note*File*Foreground:			blue",
"XPostitPlus*PostItNote*Note*AlarmIcon*Background:	gray",
"XPostitPlus*PostItNote*Note*AlarmIcon*Foreground:	blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*Background:			gray",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*Foreground:			black",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*Save*Foreground:		blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*Erase*Foreground:		blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*Destroy*Foreground:		red",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*Hide*Foreground:		blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*Name*Foreground:		blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*Anchor*Foreground:		blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*UnAnchor*Foreground:	blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*Print*Foreground:		blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*SetAlarm*Foreground:	blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*UnsetAlarm*Foreground:	blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*InsertCalendar*Foreground:	blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*InsertDate*Foreground:	blue",
"XPostitPlus*PostItNote*Note*Options*OptionsMenu*EmailNote*Foreground:	blue",
"XPostitPlus*PostItNote*Note*Label*Background:	red",
"XPostitPlus*PostItNote*Note*Label*Foreground:	white",
"XPostitPlus*PostItNote*Note*NoteText*Background:	Yellow",
"XPostitPlus*PostItNote*Note*NoteText*Foreground:	Black",
"XPostitPlus*Command*Background:	red",
"XPostitPlus*Command*Foreground:	white",
"XPostitPlus*Text*wrap:		word",
"XPostitPlus*Command*shapeStyle:	oval",
"XPostitPlus*input:			true",
"XPostitPlus*Dialog*Text.Translations: #override\\n \
	<Key>Down:		no-op(RingBell) \\n \
	<Key>Return:		no-op(RingBell) \\n \
	Ctrl<Key>M:		no-op(RingBell)",
"XPostitPlus*baseTranslations: #augment\\n\
	<Message>WM_PROTOCOLS: WMProtocols()\\n",
"XPostitPlus*Plaid.Translations: #replace\\n \
	<Btn1Down>,<Btn1Up>:	raise()	\\n\
	<Btn2Down>,<Btn2Up>:	lower()	\\n\
	<Btn1Down>,<Leave>:	tearoff() \\n\
	<Btn3Down>:	XawPositionSimpleMenu(Menu) MenuPopup(Menu) \\n\
	Alt <Key> Q:		quit() \\n\
	Alt <Key> q:		quit()",
